<?php


namespace Factory;


use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;
use Util\Utilities;
use Teknisa\Model\Teknisa\Entities\OmProdutoOrgElementoCustom as OmProdutoOrgElementoCustomEntity;

class CustomScreen
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * OqueHaDeNovo constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function findProductCustom($customerNrParc)
    {
        $query = <<<SQL
                    SELECT OMP.ID AS NRPRODUTO,
                    OMP.NMPRODUTO,
                    OMP.NREXTERNAL_PRODUCT_ID,
                    OPO.ID AS NRPRODUTO_ORG,
                    PRO.VERSION_CHECK_TYPE,
                    PRO.URL_WEBSERVICE,
                    OMP.IDPRODUTOSAAS,
                    OPO.IDPRODUTOSAAS AS IDPRODUTOORGSAAS,
                    ORG.IDORGSAAS,
                    PRJ.PRODUCT_TYPE AS PRODUCT_TYPE
            FROM OM_PRODUTO_ORG OPO
            INNER JOIN OM_PRODUTO OMP ON OPO.NRPRODUTO_ID = OMP.ID
            INNER JOIN ORGANIZACAO ORG ON ORG.NRORG = OPO.NRORG_ID
            INNER JOIN PRODUCT PRO ON PRO.ID = OMP.NREXTERNAL_PRODUCT_ID
            INNER JOIN PROJECT PRJ ON PRJ.ID = PRO.PROJECT_ID
            AND PRODUCT_TYPE = 'C'
            WHERE ORG.NRPARCNEGOCIO = :NRPARCNEGOCIO
            ORDER BY NMPRODUTO

SQL;
        $params = [
            'NRPARCNEGOCIO' => $customerNrParc,
        ];
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function findElementProduct($productId, $elementProductOrg)
    {
        $query = <<<SQL
                                SELECT * FROM (
    SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'N' AS ISNEW,
                            NULL AS ROUTE,
                            PE.ID,
                            PE.LABEL,
                            PE.UNIQUE_ID,
                            PE.NRPRODUTO_ID,
                            PE.PARENT_ID,
                            PE.NRORDEM,
                            TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'Y' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ELEMENTO PE
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
            AND NRPRODUTO_ORG_ID = :elementProductOrg
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
            LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC ON POC.PARENT_ID = PE.ID
            WHERE PE.NRPRODUTO_ID = :productId
            AND PE.ID IN
                (SELECT NRPRODUTO_ELEMENTO_ID
                FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID
                AND PO.NRORG_ID = PR.NRORG_ID)
            UNION
            SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'N' AS ISNEW,
                            NULL AS ROUTE,
                            PE.ID,
                            PE.LABEL,
                            PE.UNIQUE_ID,
                            PE.NRPRODUTO_ID,
                            PE.PARENT_ID,
                            PE.NRORDEM,
                            TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'N' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ELEMENTO PE
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
            AND NRPRODUTO_ORG_ID = :elementProductOrg
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
            LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC ON POC.PARENT_ID = PE.ID
            WHERE PE.NRPRODUTO_ID = :productId
            AND PE.ID NOT IN
                (SELECT NRPRODUTO_ELEMENTO_ID
                FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID)
            UNION
            SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'S' AS ISNEW,
                            POC.ROUTE,
                            POC.ID,
                            POC.LABEL,
                            POC.UNIQUE_ID,
                            PR.NRPRODUTO_ID,
                            POC.PARENT_ID,
                            POC.NRORDEM,
                            NULL AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                 WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'N' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC
            LEFT JOIN OM_PRODUTO_ELEMENTO PE ON PE.ID = POC.PARENT_ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = POC.PARENT_ID
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = POC.NRPRODUTO_ORG_ID
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = POC.ID
            LEFT JOIN OPERADOR OP1 ON POC.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON POC.CDOPERULTATU = OP2.CDOPERADOR
            WHERE POC.NRPRODUTO_ORG_ID = :elementProductOrg
            ORDER BY NRORDEM)
    WHERE ATIVO = 'S'
    ORDER BY NRORDEM

SQL;
        $params = [
            'productId' => $productId,
            'elementProductOrg' => $elementProductOrg,
        ];
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function findAllElementProduct($productId, $elementProductOrg)
    {
        $query = <<<SQL
    SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'N' AS ISNEW,
                            NULL AS ROUTE,
                            PE.ID,
                            PE.LABEL,
                            PE.UNIQUE_ID,
                            PE.NRPRODUTO_ID,
                            PE.PARENT_ID,
                            PE.NRORDEM,
                            TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'Y' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ELEMENTO PE
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
            AND NRPRODUTO_ORG_ID = :elementProductOrg
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
            LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC ON POC.PARENT_ID = PE.ID
            WHERE PE.NRPRODUTO_ID = :productId
            AND PE.ID IN
                (SELECT NRPRODUTO_ELEMENTO_ID
                FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID
                AND PO.NRORG_ID = PR.NRORG_ID)
            UNION
            SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'N' AS ISNEW,
                            NULL AS ROUTE,
                            PE.ID,
                            PE.LABEL,
                            PE.UNIQUE_ID,
                            PE.NRPRODUTO_ID,
                            PE.PARENT_ID,
                            PE.NRORDEM,
                            TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'N' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ELEMENTO PE
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
            AND NRPRODUTO_ORG_ID = :elementProductOrg
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
            LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC ON POC.PARENT_ID = PE.ID
            WHERE PE.NRPRODUTO_ID = :productId
            AND PE.ID NOT IN
                (SELECT NRPRODUTO_ELEMENTO_ID
                FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID)
            UNION
            SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'S' AS ISNEW,
                            POC.ROUTE,
                            POC.ID,
                            POC.LABEL,
                            POC.UNIQUE_ID,
                            PR.NRPRODUTO_ID,
                            POC.PARENT_ID,
                            POC.NRORDEM,
                            NULL AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                 WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'N' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC
            LEFT JOIN OM_PRODUTO_ELEMENTO PE ON PE.ID = POC.PARENT_ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = POC.PARENT_ID
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = POC.NRPRODUTO_ORG_ID
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = POC.ID
            LEFT JOIN OPERADOR OP1 ON POC.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON POC.CDOPERULTATU = OP2.CDOPERADOR
            WHERE POC.NRPRODUTO_ORG_ID = :elementProductOrg
            ORDER BY NRORDEM

SQL;
        $params = [
            'productId' => $productId,
            'elementProductOrg' => $elementProductOrg,
        ];
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function verficaFilhos($productId, $elementProductOrg, $parentId)
    {
        $query = <<<SQL
                                SELECT * FROM (
    SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'N' AS ISNEW,
                            NULL AS ROUTE,
                            PE.ID,
                            PE.LABEL,
                            PE.UNIQUE_ID,
                            PE.NRPRODUTO_ID,
                            PE.PARENT_ID,
                            PE.NRORDEM,
                            TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'Y' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ELEMENTO PE
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
            AND NRPRODUTO_ORG_ID = :elementProductOrg
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
            LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC ON POC.PARENT_ID = PE.ID
            WHERE PE.NRPRODUTO_ID = :productId
            AND PE.ID IN
                (SELECT NRPRODUTO_ELEMENTO_ID
                FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID
                AND PO.NRORG_ID = PR.NRORG_ID)
            UNION
            SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'N' AS ISNEW,
                            NULL AS ROUTE,
                            PE.ID,
                            PE.LABEL,
                            PE.UNIQUE_ID,
                            PE.NRPRODUTO_ID,
                            PE.PARENT_ID,
                            PE.NRORDEM,
                            TO_CHAR(OE.DTVALIDADE, 'DD/MM/YYYY') AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'N' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ELEMENTO PE
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = PE.ID
            AND NRPRODUTO_ORG_ID = :elementProductOrg
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = OE.NRPRODUTO_ORG_ID
            LEFT JOIN OPERADOR OP1 ON OE.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON OE.CDOPERULTATU = OP2.CDOPERADOR
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = OE.ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC ON POC.PARENT_ID = PE.ID
            WHERE PE.NRPRODUTO_ID = :productId
            AND PE.ID NOT IN
                (SELECT NRPRODUTO_ELEMENTO_ID
                FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC PO
                WHERE PO.NRPRODUTO_ELEMENTO_ID = PE.ID)
            UNION
            SELECT DISTINCT OP1.NMOPERADOR AS OPERINCLUSAO,
                            OP2.NMOPERADOR AS OPERULTATU,
                            'S' AS ISNEW,
                            POC.ROUTE,
                            POC.ID,
                            POC.LABEL,
                            POC.UNIQUE_ID,
                            PR.NRPRODUTO_ID,
                            POC.PARENT_ID,
                            POC.NRORDEM,
                            NULL AS DTVALIDADE,
                            :elementProductOrg AS NRPRODUTO_ORG_ID,
                            CASE
                                 WHEN PE.IDELEMENTOPADRAO = 'S'
                                    OR OE.ID IS NOT NULL
                                    OR POC.ID IS NOT NULL THEN 'S'
                                ELSE 'N'
                            END AS ATIVO,
                            OE.DSOBSERVACAO,
                            OE.DTINCLUSAO,
                            OE.DTULTATU,
                            NVL2(PC.ID, 'Y', 'N') AS IS_RELATED_TO_CONTRACT,
                            'N' AS IS_SPECIFIC_ORG,
                            PE.IDELEMENTOPADRAO
            FROM OM_PRODUTO_ORG_ELEMENTO_CUSTOM POC
            LEFT JOIN OM_PRODUTO_ELEMENTO PE ON PE.ID = POC.PARENT_ID
            LEFT JOIN OM_PRODUTO_ORG_ELEMENTO OE ON OE.NRPRODUTO_ELEMENTO_ID = POC.PARENT_ID
            LEFT JOIN OM_PRODUTO_ORG PR ON PR.ID = POC.NRPRODUTO_ORG_ID
            LEFT JOIN OM_PROD_ORG_ELEMENTO_CONTRATO PC ON PC.NRPRODUTO_ORG_ELEMENTO_ID = POC.ID
            LEFT JOIN OPERADOR OP1 ON POC.CDOPERINCLUSAO = OP1.CDOPERADOR
            LEFT JOIN OPERADOR OP2 ON POC.CDOPERULTATU = OP2.CDOPERADOR
            WHERE POC.NRPRODUTO_ORG_ID = :elementProductOrg
            ORDER BY NRORDEM)
    WHERE ATIVO = 'S' AND PARENT_ID = :ID
    ORDER BY NRORDEM

SQL;
        $params = [
            'productId' => $productId,
            'elementProductOrg' => $elementProductOrg,
            'ID'                => $parentId,
        ];
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
    }

    public function create($uniqueId, $nrprodutoOrgId, $label, $parentUniqueId, $parentId, $nrordem, $route) {
        $entity = new OmProdutoOrgElementoCustomEntity();
        $entity->setUniqueId($uniqueId);
        $entity->setNrprodutoOrgId($nrprodutoOrgId);
        $entity->setLabel($label);
        $entity->setParentUniqueId($parentUniqueId);
        $entity->setParentId($parentId);
        $entity->setNrordem($nrordem);
        $entity->setRoute($route);
        return $entity;
    }

    public function update(OmProdutoOrgElementoCustomEntity $produtoOrgElementoCustomRepository, $id, $label, $nrordem, $route, $parentId)
    {
        $produtoOrgElementoCustomRepository->setLabel($label);
        $produtoOrgElementoCustomRepository->setNrordem($nrordem);
        $produtoOrgElementoCustomRepository->setRoute($route);
        $produtoOrgElementoCustomRepository->setParentId($parentId);
        $produtoOrgElementoCustomRepository->setId($id);
        return $produtoOrgElementoCustomRepository;
    }


}