import { Utilities } from '@/util/Utilities';
import { DialogService, Form, LoadingService, Modal, ModalService, SelectTree } from '@zeedhi/common';
import { Http, I18n, Metadata, Validation } from '@zeedhi/core';
import { TekRestDatasource, TekTreeGrid } from '@zeedhi/teknisa-components-common';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import Messages from '@/services/Messages';

let backupOrder: string = '';

const invalidOrder = () => {
	const message = I18n.translate('Valor de ordem já cadastrado.');
	return (value: string[]) => {
		const menuComponent = Metadata.getInstance<SelectTree>('modalMenuAddFormMenu');
		const data = menuComponent.datasource?.data;
		if (data) {
			for (let i = 0; i < data.length; i += 1) {
				if (data[i].NRORDEM === value) {
					return message;
				}
			}
		}
		return true;
	};
};

const invalidOrderEdit = () => {
	const message = I18n.translate('Valor de ordem já cadastrado.');
	return (value: string[]) => {
		const menuComponent = Metadata.getInstance<SelectTree>('modalMenuEditFormMenu');
		const data = menuComponent.datasource?.data;
		if (data) {
			for (let i = 0; i < data.length; i += 1) {
				if (data[i].NRORDEM !== backupOrder) {
					if (data[i].NRORDEM === value) {
						return message;
					}
				}
			}
		}
		return true;
	};
};

Validation.register('invalidOrder', invalidOrder);
Validation.register('invalidOrderEdit', invalidOrderEdit);

export class CustomScreenController {
	public modalMenuAdd!: Modal;

	public modalMenuEdit!: Modal;

	public currentRow: any = {};

	public currentRowElemento: any = {};

	public currentRowElementoEdit: any = {};

	public async filterElementProduct({ row }: any) {
		this.currentRowElemento = {};
		this.currentRow = row;
		const tekTreeGridElementos = Metadata.getInstance<TekTreeGrid>('tekTreeGridElementos');
		try {
			tekTreeGridElementos.datasource.setFilter({
				productId: row.NRPRODUTO,
				elementProductOrg: row.NRPRODUTO_ORG,
			});
		} catch (e) {
			console.error(e);
		}
	}

	public async addMenu() {
		if (this.currentRowElemento.ISNEW === 'N' && this.currentRowElemento.tree__children.length === 0) {
			const msg = I18n.translate('O registro selecionado é uma tela e não pode possuir itens.');
			Utilities.showDialog('Atenção!', 'warning', msg);
		} else if (Object.keys(this.currentRow).length > 0) {
			this.modalMenuAdd = await ModalService.createFromJson('/telasCustomizadas/modal/modalMenuAdd', true);
			this.modalMenuAdd.show();
		}
	}

	public closeModalMenuAdd() {
		this.modalMenuAdd.destroy();
	}

	public async setFilterElement() {
		const menu = Metadata.getInstance<SelectTree>('modalMenuAddFormMenu');
		if (menu.datasource instanceof TekRestDatasource) {
			menu.nodes = [];
			menu.datasource.data = [];
			await menu.datasource.setFilter({
				productId: this.currentRow.NRPRODUTO,
				elementProductOrg: this.currentRow.NRPRODUTO_ORG,
			});
			await menu.setValue(this.currentRowElemento.ID);
		}
	}

	public addButton({ row }: any) {
		this.currentRowElemento = row;
	}

	public saveModalMenuAdd() {
		const form = Metadata.getInstance<Form>('modalMenuAddForm');
		const gridMenu = Metadata.getInstance<TekTreeGrid>('tekTreeGridElementos');
		console.log(form.value.modalMenuAddFormMenu);
		if (Utilities.validateForm(form)) {
			LoadingService.show();
			Http.post('/saveElementCustom', {
				NRPRODUTO_ID: this.currentRow.NRPRODUTO,
				NRPRODUTO_ORG_ID: this.currentRow.NRPRODUTO_ORG,
				LABEL: form.value.modalMenuAddFormLABEL,
				PARENT_UNIQUE_ID: form.value.modalMenuAddFormMenu.UNIQUE_ID,
				PARENT_ID: form.value.modalMenuAddFormMenu.ID,
				NRORDEM: form.value.modalMenuAddFormNRORDEM,
				ROUTE: form.value.modalMenuAddFormROUTE,
				ISNEW: form.value.modalMenuAddFormMenu.ISNEW,
			}).then(() => {
				this.currentRowElemento = {};
				gridMenu.reload();
				this.closeModalMenuAdd();
				Utilities.showSuccessMessage();
			}).catch((error) => {
				if (error.response.data.error === 'ERROR') {
					Utilities.showDialogMessage('error', 'Operação bloqueada!', I18n.translate('O menu superior selecionado é uma tela e não pode possuir itens.'));
				} else {
					Utilities.showErrorMessage(error);
				}
			}).finally(() => {
				LoadingService.hide();
			});
		}
	}

	public checkElementoIsNew({ row }: any) {
		if (row.ISNEW === 'S') {
			return true;
		}
		return false;
	}

	public async editMenu({ row }: any) {
		this.modalMenuEdit = await ModalService.createFromJson('/telasCustomizadas/modal/modalMenuEdit', true);
		this.modalMenuEdit.show();
		this.currentRowElementoEdit = row;
	}

	public closeModalMenuEdit() {
		this.modalMenuEdit.destroy();
	}

	public async setFilterElementEdit() {
		backupOrder = this.currentRowElementoEdit.NRORDEM;
		Metadata.getInstance<SelectTree>('modalMenuEditFormLABEL').value = this.currentRowElementoEdit.LABEL;
		Metadata.getInstance<SelectTree>('modalMenuEditFormNRORDEM').value = this.currentRowElementoEdit.NRORDEM;
		Metadata.getInstance<SelectTree>('modalMenuEditFormROUTE').value = this.currentRowElementoEdit.ROUTE;
		const menu = Metadata.getInstance<SelectTree>('modalMenuEditFormMenu');
		if (menu.datasource instanceof TekRestDatasource) {
			menu.nodes = [];
			menu.datasource.data = [];
			await menu.datasource.setFilter({
				productId: this.currentRow.NRPRODUTO,
				elementProductOrg: this.currentRow.NRPRODUTO_ORG,
			});
			await menu.setValue(this.currentRowElementoEdit.PARENT_ID);
		}
	}

	public editModalMenu() {
		const form = Metadata.getInstance<Form>('modalMenuEditForm');
		const gridMenu = Metadata.getInstance<TekTreeGrid>('tekTreeGridElementos');
		if (Utilities.validateForm(form)) {
			LoadingService.show();
			Http.post('/editElementCustom', {
				ID: this.currentRowElementoEdit.ID,
				LABEL: form.value.modalMenuEditFormLABEL,
				NRORDEM: form.value.modalMenuEditFormNRORDEM,
				ROUTE: form.value.modalMenuEditFormROUTE,
				PARENT_ID: form.value.modalMenuEditFormMenu.ID,
				NRPRODUTO_ID: this.currentRow.NRPRODUTO,
				NRPRODUTO_ORG_ID: this.currentRow.NRPRODUTO_ORG,
				ISNEW: form.value.modalMenuEditFormMenu.ISNEW,
			}).then(() => {
				this.currentRowElementoEdit = {};
				backupOrder = '';
				gridMenu.reload();
				this.closeModalMenuEdit();
				Utilities.showSuccessMessage();
			}).catch((error) => {
				if (error.response.data.error === 'ERROR') {
					Utilities.showDialogMessage('error', 'Operação bloqueada!', I18n.translate('O menu superior selecionado é uma tela e não pode possuir itens.'));
				} else {
					Utilities.showErrorMessage(error);
				}
			}).finally(() => {
				LoadingService.hide();
			});
		}
	}

	public async beforeDeleteElement(params: any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: () => {
						DialogService.hide();
						this.doDeleteElement(params);
					},
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

	public async doDeleteElement(params: any) {
		const gridMenu = Metadata.getInstance<TekTreeGrid>('tekTreeGridElementos');
		LoadingService.show();
		Http.post('/removeElementCustom', {
			ID: params.row.ID,
		}).then(() => {
			this.currentRowElementoEdit = {};
			backupOrder = '';
			gridMenu.reload();
			Utilities.showSuccessMessage();
		}).catch((error) => {
			Utilities.showErrorMessage(error);
		}).finally(() => {
			LoadingService.hide();
		});
	}

	public colorirLinhas(row: any) {
		if (row.ISNEW === 'S') {
			return { cssClass: 'linhaGridAzul' };
		}
		return { cssClass: 'linhaGridOpacity' };
	}

	get textProduct() {
		if (this.currentRow.NMPRODUTO) {
			return this.currentRow.NMPRODUTO;
		}
		return I18n.translate('Selecione um Produto');
	}

	public cleanCurrentRow() {
		this.currentRowElemento = {};
	}
}
